@@ -18,7 +18,7 @@
 """GPG signing and checking logic."""
 
 import os
-from typing import Dict, List, Optional
+from typing import Optional
 
 from . import config, errors, trace, ui
 from .i18n import gettext, ngettext
@@ -60,7 +60,7 @@ class SignatureVerificationFailed(errors.BzrError):
 
 
 def bulk_verify_signatures(repository, revids, strategy, process_events_callback=None):
-    """Do verifications on a set of revisions
+    """Do verifications on a set of revisions.
 
     :param repository: repository object
     :param revids: list of revision ids to verify
@@ -165,13 +165,13 @@ def _set_gpg_tty():
         # This is not quite worthy of a warning, because some people
         # don't need GPG_TTY to be set. But it is worthy of a big mark
         # in brz.log, so that people can debug it if it happens to them
-        trace.mutter("** Env var TTY empty, cannot set GPG_TTY." "  Is TTY exported?")
+        trace.mutter("** Env var TTY empty, cannot set GPG_TTY.  Is TTY exported?")
 
 
 class GPGStrategy:
     """GPG Signing and checking facilities."""
 
-    acceptable_keys: Optional[List[str]] = None
+    acceptable_keys: Optional[list[str]] = None
 
     def __init__(self, config_stack):
         self._config_stack = config_stack
@@ -212,8 +212,7 @@ class GPGStrategy:
 
     @staticmethod
     def verify_signatures_available():
-        """
-        check if this strategy can verify signatures
+        """Check if this strategy can verify signatures.
 
         :return: boolean if this strategy can verify signatures
         """
@@ -227,7 +226,7 @@ class GPGStrategy:
     def sign(self, content, mode):
         try:
             import gpg
-        except ModuleNotFoundError as error:
+        except ModuleNotFoundError:
             raise GpgNotInstalled(
                 "Set create_signatures=no to disable creating signatures."
             )
@@ -262,7 +261,7 @@ class GPGStrategy:
         """
         try:
             import gpg
-        except ModuleNotFoundError as error:
+        except ModuleNotFoundError:
             raise GpgNotInstalled(
                 "Set check_signatures=ignore to disable verifying signatures."
             )
@@ -296,14 +295,12 @@ class GPGStrategy:
 
             return SIGNATURE_NOT_VALID, None, None
         except gpg.errors.GPGMEError as error:
-            try:
-                # No result if input is invalid.
-                # test_verify_invalid()
-                if len(error.results[1].signatures) == 0:
-                    plain_output = error.results[0]
-                    return SIGNATURE_NOT_VALID, None, plain_output
-            except Exception:
-                raise SignatureVerificationFailed(error)
+            raise SignatureVerificationFailed(error)
+
+        # No result if input is invalid.
+        # test_verify_invalid()
+        if len(result.signatures) == 0:
+            return SIGNATURE_NOT_VALID, None, plain_output
 
         # User has specified a list of acceptable keys, check our result is in
         # it.  test_verify_unacceptable_key()
@@ -370,12 +367,12 @@ class GPGStrategy:
 
 
 def valid_commits_message(count):
-    """returns message for number of commits"""
+    """Returns message for number of commits."""
     return gettext("{0} commits with valid signatures").format(count[SIGNATURE_VALID])
 
 
 def unknown_key_message(count):
-    """returns message for number of commits"""
+    """Returns message for number of commits."""
     return ngettext(
         "{0} commit with unknown key",
         "{0} commits with unknown keys",
@@ -384,21 +381,21 @@ def unknown_key_message(count):
 
 
 def commit_not_valid_message(count):
-    """returns message for number of commits"""
+    """Returns message for number of commits."""
     return ngettext(
         "{0} commit not valid", "{0} commits not valid", count[SIGNATURE_NOT_VALID]
     ).format(count[SIGNATURE_NOT_VALID])
 
 
 def commit_not_signed_message(count):
-    """returns message for number of commits"""
+    """Returns message for number of commits."""
     return ngettext(
         "{0} commit not signed", "{0} commits not signed", count[SIGNATURE_NOT_SIGNED]
     ).format(count[SIGNATURE_NOT_SIGNED])
 
 
 def expired_commit_message(count):
-    """returns message for number of commits"""
+    """Returns message for number of commits."""
     return ngettext(
         "{0} commit with key now expired",
         "{0} commits with key now expired",
@@ -406,9 +403,9 @@ def expired_commit_message(count):
     ).format(count[SIGNATURE_EXPIRED])
 
 
-def verbose_expired_key_message(result, repo) -> List[str]:
-    """takes a verify result and returns list of expired key info"""
-    signers: Dict[str, int] = {}
+def verbose_expired_key_message(result, repo) -> list[str]:
+    """Takes a verify result and returns list of expired key info."""
+    signers: dict[str, int] = {}
     fingerprint_to_authors = {}
     for rev_id, validity, fingerprint in result:
         if validity == SIGNATURE_EXPIRED:
@@ -417,7 +414,7 @@ def verbose_expired_key_message(result, repo) -> List[str]:
             signers.setdefault(fingerprint, 0)
             signers[fingerprint] += 1
             fingerprint_to_authors[fingerprint] = authors
-    ret: List[str] = []
+    ret: list[str] = []
     for fingerprint, number in signers.items():
         ret.append(
             ngettext(
@@ -429,14 +426,14 @@ def verbose_expired_key_message(result, repo) -> List[str]:
     return ret
 
 
-def verbose_valid_message(result) -> List[str]:
-    """takes a verify result and returns list of signed commits strings"""
-    signers: Dict[str, int] = {}
-    for rev_id, validity, uid in result:
+def verbose_valid_message(result) -> list[str]:
+    """Takes a verify result and returns list of signed commits strings."""
+    signers: dict[str, int] = {}
+    for _rev_id, validity, uid in result:
         if validity == SIGNATURE_VALID:
             signers.setdefault(uid, 0)
             signers[uid] += 1
-    ret: List[str] = []
+    ret: list[str] = []
     for uid, number in signers.items():
         ret.append(
             ngettext("{0} signed {1} commit", "{0} signed {1} commits", number).format(
@@ -446,16 +443,16 @@ def verbose_valid_message(result) -> List[str]:
     return ret
 
 
-def verbose_not_valid_message(result, repo) -> List[str]:
-    """takes a verify result and returns list of not valid commit info"""
-    signers: Dict[str, int] = {}
-    for rev_id, validity, empty in result:
+def verbose_not_valid_message(result, repo) -> list[str]:
+    """Takes a verify result and returns list of not valid commit info."""
+    signers: dict[str, int] = {}
+    for rev_id, validity, _empty in result:
         if validity == SIGNATURE_NOT_VALID:
             revision = repo.get_revision(rev_id)
             authors = ", ".join(revision.get_apparent_authors())
             signers.setdefault(authors, 0)
             signers[authors] += 1
-    ret: List[str] = []
+    ret: list[str] = []
     for authors, number in signers.items():
         ret.append(
             ngettext(
@@ -465,16 +462,16 @@ def verbose_not_valid_message(result, repo) -> List[str]:
     return ret
 
 
-def verbose_not_signed_message(result, repo) -> List[str]:
-    """takes a verify result and returns list of not signed commit info"""
-    signers: Dict[str, int] = {}
-    for rev_id, validity, empty in result:
+def verbose_not_signed_message(result, repo) -> list[str]:
+    """Takes a verify result and returns list of not signed commit info."""
+    signers: dict[str, int] = {}
+    for rev_id, validity, _empty in result:
         if validity == SIGNATURE_NOT_SIGNED:
             revision = repo.get_revision(rev_id)
             authors = ", ".join(revision.get_apparent_authors())
             signers.setdefault(authors, 0)
             signers[authors] += 1
-    ret: List[str] = []
+    ret: list[str] = []
     for authors, number in signers.items():
         ret.append(
             ngettext(
@@ -484,14 +481,14 @@ def verbose_not_signed_message(result, repo) -> List[str]:
     return ret
 
 
-def verbose_missing_key_message(result) -> List[str]:
-    """takes a verify result and returns list of missing key info"""
-    signers: Dict[str, int] = {}
-    for rev_id, validity, fingerprint in result:
+def verbose_missing_key_message(result) -> list[str]:
+    """Takes a verify result and returns list of missing key info."""
+    signers: dict[str, int] = {}
+    for _rev_id, validity, fingerprint in result:
         if validity == SIGNATURE_KEY_MISSING:
             signers.setdefault(fingerprint, 0)
             signers[fingerprint] += 1
-    ret: List[str] = []
+    ret: list[str] = []
     for fingerprint, number in list(signers.items()):
         ret.append(
             ngettext(
