@@ -32,8 +32,7 @@ __all__ = ["UTextWrapper", "fill", "wrap"]
 
 
 class UTextWrapper(textwrap.TextWrapper):
-    """
-    Extend TextWrapper for Unicode.
+    """Extend TextWrapper for Unicode.
 
     This textwrapper handles east asian double width and split word
     even if !break_long_words when word contains double width
@@ -67,7 +66,7 @@ class UTextWrapper(textwrap.TextWrapper):
         else:
             raise ValueError("ambiguous_width should be 1 or 2")
 
-        self.max_lines = kwargs.get("max_lines", None)
+        self.max_lines = kwargs.get("max_lines")
         textwrap.TextWrapper.__init__(self, width, **kwargs)
 
     def _unicode_char_width(self, uc):
@@ -90,7 +89,7 @@ class UTextWrapper(textwrap.TextWrapper):
         return sum(charwidth(c) for c in s)
 
     def _cut(self, s, width):
-        """Returns head and rest of s. (head+rest == s)
+        """Returns head and rest of s. (head+rest == s).
 
         Head is large as long as _width(head) <= width.
         """
@@ -103,7 +102,7 @@ class UTextWrapper(textwrap.TextWrapper):
         return s, ""
 
     def _fix_sentence_endings(self, chunks):
-        """_fix_sentence_endings(chunks : [string])
+        r"""_fix_sentence_endings(chunks : [string]).
 
         Correct for sentence endings buried in 'chunks'.  Eg. when the
         original text contains "... foo.\nBar ...", munge_whitespace()
@@ -128,7 +127,7 @@ class UTextWrapper(textwrap.TextWrapper):
         # Figure out when indent is larger than the specified width, and make
         # sure at least one character is stripped off on every pass
         if width < 2:
-            space_left = chunks[-1] and self._width(chunks[-1][0]) or 1
+            space_left = (chunks[-1] and self._width(chunks[-1][0])) or 1
         else:
             space_left = width - cur_len
 
@@ -157,7 +156,7 @@ class UTextWrapper(textwrap.TextWrapper):
     def _wrap_chunks(self, chunks):
         lines = []
         if self.width <= 0:
-            raise ValueError("invalid width %r (must be > 0)" % self.width)
+            raise ValueError("invalid width {!r} (must be > 0)".format(self.width))
         if self.max_lines is not None:
             if self.max_lines > 1:
                 indent = self.subsequent_indent
@@ -223,12 +222,16 @@ class UTextWrapper(textwrap.TextWrapper):
                     self.max_lines is None
                     or len(lines) + 1 < self.max_lines
                     or (
-                        not chunks
-                        or self.drop_whitespace
-                        and len(chunks) == 1
-                        and not chunks[0].strip()
+                        (
+                            not chunks
+                            or (
+                                self.drop_whitespace
+                                and len(chunks) == 1
+                                and not chunks[0].strip()
+                            )
+                        )
+                        and cur_len <= width
                     )
-                    and cur_len <= width
                 ):
                     # Convert current line back to a string and store it in
                     # list of all lines (return value).
